summaryrefslogtreecommitdiff
path: root/bin
diff options
context:
space:
mode:
authorTodd C. Miller <millert@cvs.openbsd.org>2001-03-26 15:22:17 +0000
committerTodd C. Miller <millert@cvs.openbsd.org>2001-03-26 15:22:17 +0000
commitd45c8b3f829b47610352a1d3361eb67b5841b2f8 (patch)
treeb0e5e35f0b84b2b4c8efc9cb88c64cadf2353162 /bin
parent7240a71adeb2b07657ea49e436e0c20a11c75208 (diff)
Fix comments, it is "daylight saving time", not "daylight savings time"
Diffstat (limited to 'bin')
-rw-r--r--bin/date/date.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/bin/date/date.c b/bin/date/date.c
index 2cd84004f73..05525d0c963 100644
--- a/bin/date/date.c
+++ b/bin/date/date.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: date.c,v 1.16 2000/11/09 23:31:56 aaron Exp $ */
+/* $OpenBSD: date.c,v 1.17 2001/03/26 15:22:16 millert Exp $ */
/* $NetBSD: date.c,v 1.11 1995/09/07 06:21:05 jtc Exp $ */
/*
@@ -44,7 +44,7 @@ static char copyright[] =
#if 0
static char sccsid[] = "@(#)date.c 8.2 (Berkeley) 4/28/95";
#else
-static char rcsid[] = "$OpenBSD: date.c,v 1.16 2000/11/09 23:31:56 aaron Exp $";
+static char rcsid[] = "$OpenBSD: date.c,v 1.17 2001/03/26 15:22:16 millert Exp $";
#endif
#endif /* not lint */
@@ -88,7 +88,7 @@ main(argc, argv)
rflag = 0;
while ((ch = getopt(argc, argv, "d:nr:ut:")) != -1)
switch((char)ch) {
- case 'd': /* daylight savings time */
+ case 'd': /* daylight saving time */
tz.tz_dsttime = atoi(optarg) ? 1 : 0;
break;
case 'n': /* don't set network */
@@ -116,7 +116,7 @@ main(argc, argv)
argv += optind;
/*
* If -d or -t, set the timezone or daylight savings time; this
* doesn't belong here, the kernel should not know about either.
*/
if ((tz.tz_minuteswest || tz.tz_dsttime) &&
@@ -116,7 +116,7 @@ main(argc, argv)
argv += optind;
/*
- * If -d or -t, set the timezone or daylight savings time; this
+ * If -d or -t, set the timezone or daylight saving time; this
* doesn't belong here, the kernel should not know about either.
*/